@@ -31,11 +31,15 @@ sub FILE_ATTRIBUTE_NORMAL () {0x80}
 sub FILE_ATTRIBUTE_NOT_CONTENT_INDEXED () {0x2000}
 sub FILE_ATTRIBUTE_NO_SCRUB_DATA () {0x20000}
 sub FILE_ATTRIBUTE_OFFLINE () {0x1000}
+sub FILE_ATTRIBUTE_PINNED () {0x80000}
 sub FILE_ATTRIBUTE_READONLY () {0x1}
+sub FILE_ATTRIBUTE_RECALL_ON_DATA_ACCESS () {0x400000}
+sub FILE_ATTRIBUTE_RECALL_ON_OPEN () {0x40000}
 sub FILE_ATTRIBUTE_REPARSE_POINT () {0x400}
 sub FILE_ATTRIBUTE_SPARSE_FILE () {0x200}
 sub FILE_ATTRIBUTE_SYSTEM () {0x4}
 sub FILE_ATTRIBUTE_TEMPORARY () {0x100}
+sub FILE_ATTRIBUTE_UNPINNED () {0x100000}
 sub FILE_ATTRIBUTE_VIRTUAL () {0x10000}
 
 sub FILE_CASE_PRESERVED_NAMES () {0x00000002}
@@ -81,11 +85,15 @@ BEGIN
     FILE_ATTRIBUTE_NOT_CONTENT_INDEXED
     FILE_ATTRIBUTE_NO_SCRUB_DATA
     FILE_ATTRIBUTE_OFFLINE
+    FILE_ATTRIBUTE_PINNED
     FILE_ATTRIBUTE_READONLY
+    FILE_ATTRIBUTE_RECALL_ON_DATA_ACCESS
+    FILE_ATTRIBUTE_RECALL_ON_OPEN
     FILE_ATTRIBUTE_REPARSE_POINT
     FILE_ATTRIBUTE_SPARSE_FILE
     FILE_ATTRIBUTE_SYSTEM
     FILE_ATTRIBUTE_TEMPORARY
+    FILE_ATTRIBUTE_UNPINNED
     FILE_ATTRIBUTE_VIRTUAL
     );
   my @aVolFlags = qw(
@@ -117,7 +125,7 @@ BEGIN
     fileattr => [@aAttribs],
     volflags => [@aVolFlags]
     );
-  $VERSION = '2.1';
+  $VERSION = '2.2';
   require XSLoader;
   XSLoader::load ('Win32::LongPath', $VERSION);
   }
@@ -1474,8 +1482,14 @@ C<Win32::LongPath::> prefix.
 
 =item FILE_ATTRIBUTE_OFFLINE
 
+=item FILE_ATTRIBUTE_PINNED
+
 =item FILE_ATTRIBUTE_READONLY
 
+=item FILE_ATTRIBUTE_RECALL_ON_DATA_ACCESS
+
+=item FILE_ATTRIBUTE_RECALL_ON_OPEN
+
 =item FILE_ATTRIBUTE_REPARSE_POINT
 
 =item FILE_ATTRIBUTE_SPARSE_FILE
@@ -1484,6 +1498,8 @@ C<Win32::LongPath::> prefix.
 
 =item FILE_ATTRIBUTE_TEMPORARY
 
+=item FILE_ATTRIBUTE_UNPINNED
+
 =item FILE_ATTRIBUTE_VIRTUAL
 
 =back
